Demultiplexer2
Introduction
Demultiplexer2 is a Python package designed to efficiently demultiplex paired-end Illumina sequencing reads by identifying and sorting inline tags, enabling streamlined downstream analysis.
Installation
You can install demultiplexer2 using pip:
pip install demultiplexer2
When updates are released, users will be notified and can upgrade to the latest version with:
pip install --upgrade demultiplexer2
Usage
A primerset is a configuration file that stores details about the primers and tags used for a specific dataset. It is automatically saved in the /demultiplexer2/data directory for future use.
Step 1: Create a Primer Set
To create a new primerset, use the following command:
demultiplexer2 create_primerset --name NameOfPrimerset --n_primers NumberOfPrimers
- --name: Specifies the name of the primerset (e.g., fwh2F2-fwhR2n).
- --n_primers: Indicates the number of primers in your dataset.
The primerset is an Excel file that contains critical information organized into three sheets:
- General Information: Stores details about the primers used for amplification.
- Forward Tags: Contains the names and sequences of the tags associated with the forward primers.
- Reverse Tags: Contains the names and sequences of the tags associated with the reverse primers.
Fill out the primerset file before continuing with the next step.
Step 2: Create a Tagging scheme
To create a new tagging scheme, use the following command:
demultiplexer2 create_tagging_scheme --name NameOfTaggingScheme --data_dir InputDirectory --primerset_path PathToPrimerset
- --name: Specifies the name of the tagging scheme (e.g., MyFirstStudy).
- --data_dir: Specifies the directory with all files you want to demultiplex (gzipped fastq files).
- --primerset_path: Specifies the path to the primerset you want to use to demultiplex this dataset.
The tagging scheme is an Excel file that links your input files to sample names after demultiplexing. It will be save to the current working directory. The sample names have to be added in the tagging scheme. Fill out the tagging scheme before continuing with the next step.
Step 3: Demultiplex
To run the demultiplexing algorithm use this command:
demultiplexer2 demultiplex --primerset_path PathToPrimerset --tagging_scheme_path PathToTaggingScheme --output_dir OutputDirectory
- --primerset_path: Specifies the path to the primerset you want to use to demultiplex this dataset.
- --tagging_scheme_path: Specifies the path to the tagging scheme you want to use to demultiplex this dataset.
- --output_dir: Specifies the output directory to write to.
Given this information, demultiplexer2 will demultiplex your input to your output directory and give some statistics about how many reads could be assigned to tags. Unmatched reads will be directly discarded. The output will be gzipped fastq files.
08:58:58: TEST_001_r1.fastq.gz - TEST_001_r2.fastq.gz: 16865 of 100000 sequences matched the provided tag sequences (16.86 %)
Metadata
Release files for demultiplexer2 1.1.6
For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.
Source distribution (sdist)
| File | Size | Uploaded | Provenance | Actions |
|---|---|---|---|---|
| demultiplexer2-1.1.6.tar.gz | 23.4 kB | Without provenance | Details for demultiplexer2-1.1.6.tar.gz |
Built distribution (wheel)
| File | Interpreter | ABI | Platform | Actions Reset |
|---|---|---|---|---|
| demultiplexer2-1.1.6-py3-none-any.whl | Python 3 | none | any | Details for demultiplexer2-1.1.6-py3-none-any.whl |
Total release size: 46.3 kB
Release files / demultiplexer2-1.1.6.tar.gz
| Download URL | demultiplexer2-1.1.6.tar.gz |
|---|---|
| Size | 23.4 kB |
| Tags | Source |
|
SHA-256 checksum How to use checksums |
e839fa99576a2d39c7897a24cdb802af16329e4776dd7d0aecce272dc28774f5
|
|
BLAKE2b-256 checksum How to use checksums |
fd6da7a98c0120dd381568294e13f40c29c08c9b6eeab8be77dd20358ee4248e
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/6.1.0 CPython/3.13.2
|
Release files / demultiplexer2-1.1.6-py3-none-any.whl
| Download URL | demultiplexer2-1.1.6-py3-none-any.whl |
|---|---|
| Size | 22.9 kB |
| Tags | Python 3 |
|
SHA-256 checksum How to use checksums |
f78ce16ba588fd675876acd5fd98ad93b922e37927a29390e65cfbcd427a6280
|
|
BLAKE2b-256 checksum How to use checksums |
c630c91c57ff13be7be2d005e1144ac2e0276f83e78c480818492ba5ef8e6fed
|
| Upload date | |
|
Uploaded using Trusted Publishing? What is trusted publishing? |
No |
| Uploaded via |
twine/6.1.0 CPython/3.13.2
|
Security for demultiplexer2 1.1.6
Provenance
Provenance describes where a file came from. On PyPI, provenance is shared via attestations, which provide a verifiable record of the build or publishing details. View details, limitations and caveats.
No provenance found
None of the files in this release were uploaded with provenance metadata.
A note on package security
PyPI is a repository for distributing packages, not a service for auditing them. While third-party security researchers and our staff do their best to detect and remove malicious packages, PyPI cannot guarantee the quality, security or suitability of any given package.
To learn more about protecting yourself from malicious actors, visit our package security documentation.